#!/bin/sh
#   Copyright (c) 2011 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Michael Tross <michael.tross@aizo.com>
#
#   This file is part of digitalSTROM Server.
#
#   mailinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   mailinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with netinfo.sh. If not, see <http://www.gnu.org/licenses/>.

CONSOLE_MODE=0

if [[ "$1" == "console" ]]; then
    CONSOLE_MODE=1
fi

if [[ "$CONSOLE_MODE" -eq "0" ]]; then
    echo "Content-Type: application/json"
    echo ""
fi

# source common functions
. ./errlib.sh
. ./jsonlib.sh

CONFIG_FILE="/etc/msmtprc"

# json_info host from user password authOnOff sslOnOff tlsOnOff certOnOff admin
json_info() {
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        echo -n "{ \"success\": true, \"code\": $ERR_OK, \"message\": \"OK\", "
        echo -n "\"data\": { "
        echo -n "\"host\": \"$1\",  \"from\": \"$2\", \"user\": \"$3\", "
        echo -n "\"password\": \"$4\", \"authOnOff\": \"$5\", \"sslOnOff\": \"$6\", "
        echo -n "\"tlsOnOff\": \"$7\", \"certOnOff\": \"$8\", \"admin\": \"$9\" }"
        echo    " }"
    else
        echo "$1:$2:$3:$4:$5:$6:$7:$8:$9"
    fi
}

if [[ ! -f $CONFIG_FILE ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_MODE "Could not determine mail settings!"
    fi
    exit 1
fi

MAILHOST=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^host" | cut -d " " -f 2`
MAILFROM=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^from" | cut -d " " -f 2`
MAILUSER=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^user" | cut -d " " -f 2`
MAILPASSWORD=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^password" | cut -d " " -f 2`
MAILAUTH=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^auth" | cut -d " " -f 2`
MAILSSL=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^tls [onf]" | cut -d " " -f 2`
MAILTLS=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^tls_starttls" | cut -d " " -f 2`
MAILCERT=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^tls_certcheck" | cut -d " " -f 2`
MAILADMIN=`cat $CONFIG_FILE | sed -n '/^account/,$p' | grep "^admin" | cut -d " " -f 2`
[[ "$MAILTLS" == "on" ]] && MAILSSL="off"

if [[ -z "$MAILHOST" ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_MODE "Could not determine mail server settings!"
    fi
fi

if [[ -z "$MAILFROM" ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_MASK "Failed to determine mail sender address!"
    fi
fi

json_info "$MAILHOST" "$MAILFROM" "$MAILUSER" "$MAILPASSWORD" "$MAILAUTH" "$MAILSSL" "$MAILTLS" "$MAILCERT" "$MAILADMIN"
