#!/bin/sh
#   Copyright (c) 2011 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./netlib.sh
. ./util.sh

HOSTNAME_FILE="/etc/hostname"
DSS_STATE_FILE="/etc/runit/dss/supervise/stat"
MT_STATE_FILE="/etc/runit/mediatomb/supervise/stat"
MT_CONFIG_FILE="/etc/mediatomb/config.xml"
UPNP_BEACON_CONFIG_FILE="/etc/upnpbeacon.cfg"
UPNP_BEACON_SCRIPT="/etc/init.d/upnpbeacon"

set_hostname() {
    OLD_HOSTNAME=`hostname`

    echo "$1" > "$HOSTNAME_FILE"
    if [[ "$?" -ne "0" ]]; then
        log "Failed to write hostname file"
        return $ERR_FWRITE
    fi

    hostname -F "$HOSTNAME_FILE" 1>&2
    if [[ "$?" -ne "0" ]]; then
        log "Could not set hostname: hostame command returned error"
        return $ERR_HOSTNAME
    fi

    SET_HOSTNAME=`hostname`
    if [[ "$SET_HOSTNAME" != "$1" ]]; then
        echo "$OLD_HOSTNAME" > "$HOSTNAME_FILE"
        log "Invalid hostname specified, resetting back to old configuration"
        return $ERR_HOSTNAME
    fi

    # restart avahi to announce the new hostname
    if [[ -x /etc/init.d/avahi-daemon ]]; then
        /etc/init.d/avahi-daemon restart > /dev/null 2>&1
    fi

    RET=$(restart_net_with_redirect)
    RETCODE="$?"
    if [[ "$RETCODE" -ne "$ERR_OK" ]]; then
        log "Could not restart network, code $RETCODE"
        return $RETCODE
    fi

    SURVIVE=`echo $RET | cut -d ":" -f 2`
    if [[ "$SURVIVE" -eq "1" ]]; then
        REDIR=$(redirect $RET $2)
        if [[ $? -eq $ERR_REDIRECT ]]; then
            echo "$REDIR"
            return $ERR_REDIRECT
        fi
    else
        # if the browser was using the name and not the ip when opening the
        # page, it won't reach us anymore when the name changes. so we will
        # always force a redirect when changing the hostname, even if the ip
        # stayed the same
        if [[ "$OLD_HOSTNAME" != "$SET_HOSTNAME" ]]; then
            IP=$(get_current_ip)
            NETMASK=$(get_current_netmask)
            # no recovery if below fails
            if [[ -n "$IP" ]] && [[ -n "$NETMASK" ]]; then
                echo "$IP:$NETMASK"
                log "Set name returning $ERR_REDIRECT_NAME with data $IP:$NETMASK"
                return $ERR_REDIRECT_NAME
            fi
        fi
    fi

    return $ERR_OK
}

set_upnp_friendly_name() {
    if [[ -f "$MT_CONFIG_FILE" ]]; then
        OLD_NAME=$(cat "$MT_CONFIG_FILE" |sed -n -e 's/.*<name>\(.*\)<\/name>.*/\1/p')
        sed -i s:"<name>$OLD_NAME</name>":"<name>$1</name>":g "$MT_CONFIG_FILE"

        NEW_NAME=$(cat "$MT_CONFIG_FILE" |sed -n -e 's/.*<name>\(.*\)<\/name>.*/\1/p')

        if [[ "$NEW_NAME" != "$1" ]]; then
            return $ERR_UPNPNAME
        fi

        MT_STATE=
        if [[ -f "$MT_STATE_FILE" ]]; then
            MT_STATE=`cat "$MT_STATE_FILE"`
            if [[ "$DSS_STATE" == "run" ]]; then
                sv -w 5 down /etc/runit/mediatomb 1>&2
                sleep 1
                sv -w 15 up /etc/runit/mediatomb 1>&2
            fi
        fi

    fi

    if [[ -f "$UPNP_BEACON_CONFIG_FILE" ]]; then
        grep -v "upnp-name" "$UPNP_BEACON_CONFIG_FILE" >/tmp/upnp.rename
        echo "upnp-name = \"$1\";" >> /tmp/upnp.rename
        mv /tmp/upnp.rename "$UPNP_BEACON_CONFIG_FILE"
        if [[ -x "$UPNP_BEACON_SCRIPT" ]]; then
            $UPNP_BEACON_SCRIPT restart 1>&2
        fi
    fi
    return 0
}

